@@ -8,11 +8,10 @@
 */
 
 #include "animator.h"
-#include <kdebug.h>
 
 Animator::Animator()
 {
-    connect(&m_timer, SIGNAL(timeout()), this, SLOT(tick()));
+    connect(&m_timer, &QTimer::timeout, this, &Animator::tick);
 }
 
 void Animator::add(Animation* a)
@@ -44,6 +43,6 @@ void Animator::tick()
 }
 
 
-#include "animator.moc"
+
 
 
